@@ -5,7 +5,7 @@
 // it at http://www.gnu.org/.
 
 // Aspell implementation header file.
-// Applications that just use the aspell library should not include 
+// Applications that just use the Aspell library should not include 
 // these files as they are subject to change.
 // Aspell Modules MUST include some of the implementation files and
 // spell checkers MAY include some of these files.
@@ -36,15 +36,17 @@ namespace acommon {
 
   struct CheckInfo {
     const CheckInfo * next;
-    const char * word; // generally the root
-    const char * pre_strip;
+    ParmString word; // generally the root
+    short pre_strip_len;
+    short pre_add_len;
     const char * pre_add;
-    const char * suf_strip;
+    short suf_strip_len;
+    short suf_add_len;
     const char * suf_add;
-    int pre_flag;
-    int suf_flag;
-    int guess;
-    int compound;
+    short pre_flag;
+    short suf_flag;
+    short guess;
+    short compound;
   };
 
   class Speller : public CanHaveError
@@ -54,8 +56,8 @@ namespace acommon {
     Speller(const Speller &);
     Speller & operator= (const Speller &);
   public:
-    CharVector temp_str_0;
-    CharVector temp_str_1;
+    String temp_str_0;
+    String temp_str_1;
     ClonePtr<Convert> to_internal_;
     ClonePtr<Convert> from_internal_;
   protected:
