@@ -26,11 +26,10 @@ namespace acommon {
 
 namespace aspeller {
 
-  struct LocalDict;
-  struct LocalDictInfo;
-  class LocalDictList;
+  class Dictionary;
+  class DictList;
   typedef Enumeration<WordEntry *> WordEntryEnumeration;
-  typedef Enumeration<const LocalDict *> DictsEnumeration;
+  typedef Enumeration<Dictionary *> DictsEnumeration;
 
   class SoundslikeEnumeration 
   {
@@ -66,7 +65,7 @@ namespace aspeller {
     class Id;
   protected:
     CopyPtr<Id> id_;
-    virtual void set_lang_hook(const Config *) {}
+    virtual void set_lang_hook(Config &) {}
     
   public:
     typedef Id CacheKey;
@@ -83,8 +82,9 @@ namespace aspeller {
 
     const Id & id() {return *id_;}
     PosibErr<void> check_lang(ParmString lang);
-    PosibErr<void> set_check_lang(ParmString lang, const Config *);
-    const Language * lang() const {return lang_;};
+    PosibErr<void> set_check_lang(ParmString lang, Config &);
+    const LangImpl * lang() const {return lang_;};
+    const Language * language() const {return lang_;};
     const char * lang_name() const;
 
   private:
@@ -94,10 +94,11 @@ namespace aspeller {
     PosibErr<void> update_file_info(FStream & f);
   public:
     bool compare(const Dictionary &);
+
     const char * file_name() const {return file_name_.path.c_str();}
     // returns any additional dictionaries that are also used
-    virtual PosibErr<void> load(ParmString, const Config &, LocalDictList * = 0, 
-                                SpellerImpl * = 0, const LocalDictInfo * = 0);
+    virtual PosibErr<void> load(ParmString, Config &, DictList * = 0, 
+                                SpellerImpl * = 0);
 
     virtual PosibErr<void> merge(ParmString);
     virtual PosibErr<void> synchronize();
@@ -106,16 +107,21 @@ namespace aspeller {
     virtual PosibErr<void> clear();
 
     bool affix_compressed;
-    bool have_soundslike; // only true when there is true phonet data
+    bool invisible_soundslike; // true when words are grouped by the
+                               // soundslike but soundslike data is not
+                               // actually stored with the word
+    bool soundslike_root_only; // true when affix compression is used AND
+                               // the stored soundslike corresponds to the
+                               // root word only
     bool fast_scan;  // can effectly scan for all soundslikes (or
-                     // stripped words if have_soundslike is false)
+                     // clean words if have_soundslike is false)
                      // with an edit distance of 1 or 2
     bool fast_lookup; // can effectly find all words with a given soundslike
                       // when the SoundslikeWord is not given
     
     typedef WordEntryEnumeration        Enum;
     typedef const char *                Value;
-    typedef size_t                      Size;
+    typedef unsigned int                Size;
 
     StringEnumeration * elements() const;
 
@@ -123,10 +129,10 @@ namespace aspeller {
     virtual Size   size()     const;
     virtual bool   empty()    const;
   
-    virtual bool lookup (ParmString word, WordEntry &,
-                         const SensitiveCompare &) const;
+    virtual bool lookup (ParmString word, const SensitiveCompare *, 
+                         WordEntry &) const;
     
-    virtual bool stripped_lookup(ParmString, WordEntry &) const;
+    virtual bool clean_lookup(ParmString, WordEntry &) const;
 
     virtual bool soundslike_lookup(const WordEntry &, WordEntry &) const;
     virtual bool soundslike_lookup(ParmString, WordEntry & o) const;
@@ -164,38 +170,21 @@ namespace aspeller {
     return !(rhs == lhs);
   }
 
-  struct LocalDictInfo 
-  {
-    SensitiveCompare compare;
-    ConvertWord      convert;
-    void set_language(const Language * l);
-    void set(const Language * l, const Config & c, bool strip = false);
-    void set(const LocalDictInfo & li) {operator=(li);}
-  };
-
-  struct LocalDict : public LocalDictInfo {
-    Dict * dict;
-    LocalDict(Dict * d = 0) : dict(d) {}
-    LocalDict(Dict * d, LocalDictInfo li)
-      : LocalDictInfo(li), dict(d) {}
-    operator bool () const {return dict != 0;}
-  };
-
-  class LocalDictList {
+  class DictList {
     // well a stack at the moment but it may eventually become a list
     // NOT necessarily first in first out
-    Vector<LocalDict> data;
+    Vector<Dict *> data;
   private:
-    LocalDictList(const LocalDictList &);
-    void operator= (const LocalDictList &);
+    DictList(const DictList &);
+    void operator= (const DictList &);
   public:
     // WILL take ownership of the dict
-    LocalDictList() {}
-    void add(const LocalDict & o) {data.push_back(o);}
-    LocalDict & last() {return data.back();}
+    DictList() {}
+    void add(Dict * o) {data.push_back(o);}
+    Dict * last() {return data.back();}
     void pop() {data.pop_back();}
     bool empty() {return data.empty();}
-    ~LocalDictList() {for (; !empty(); pop()) last().dict->release();}
+    ~DictList() {for (; !empty(); pop()) last()->release();}
   };
 
   typedef unsigned int DataType;
@@ -205,16 +194,13 @@ namespace aspeller {
   static const DataType DT_Multi        = 1<<3;
   static const DataType DT_Any          = 0xFF;
 
-  // stores result in LocalDict
   // any new extra dictionaries that were loaded will be ii
-  PosibErr<void> add_data_set(ParmString file_name,
-                              const Config &,
-                              LocalDict &,
-                              LocalDictList * other_dicts = 0,
-                              SpellerImpl * = 0,
-                              const LocalDictInfo * local_info = 0,
-                              ParmString dir = 0,
-                              DataType allowed = DT_Any);
+  PosibErr<Dict *> add_data_set(ParmString file_name,
+                                Config &,
+                                DictList * other_dicts = 0,
+                                SpellerImpl * = 0,
+                                ParmString dir = 0,
+                                DataType allowed = DT_Any);
   
   // implemented in readonly_ws.cc
   Dictionary * new_default_readonly_dict();
